jQuery(function ($) {

    function WpReactionsFront(data) {
        this.data = data;
        this.can_user_react = true;
        this.all_emoji_containers = [];
        this.center_on_top_css = {
            left: {'left': 0, 'right': 'unset', 'width': 'auto'},
            center: {'justify-content': 'center', 'width': '100%'},
            right: {'right': 0, 'left': 'unset', 'width': 'auto'}
        };
        this.init();
    }

    WpReactionsFront.prototype.init = function () {
        let self = this;

        this.register_events();
        this.animate_emojis();

        $('.wpra-plugin-container').each(function () {
            let $plugin_container = $(this);

            // if it is regular reactions check if it needs narrowing
            if ($plugin_container.hasClass('wpra-regular')) {
                // if classic reactions does not fit to its container then narrow it
                if ($plugin_container.find('.wpra-reactions').outerWidth() > $plugin_container.parent().width()) {
                    self.narrowContainerize($plugin_container);
                } else {
                    $plugin_container.addClass('wpra-rendered');
                }
            }

            if ($plugin_container.hasClass('wpra-button-reveal')) {
                let $reactions = $plugin_container.find('.wpra-reactions-container');
                let emoji_id = $plugin_container.find('.wpra-reaction.active').data('emoji_id');
                if (typeof emoji_id === "undefined") return;

                let reveal_wrap = $plugin_container.find('.wpra-button-reveal-wrap');
                let $reacted_emoji = reveal_wrap.find('.wpra-reacted-emoji');
                let $badge = $plugin_container.find('.wpra-reaction.active .arrow-badge').clone();
                let $reveal_toggle = reveal_wrap.find('.wpra-reveal-toggle');

                self.load_lottie_emoji({
                    container: $reactions,
                    emoji_elem: reveal_wrap.find('.wpra-reacted-emoji'),
                    emoji_id: emoji_id,
                    onComplete: function () {
                        let size = $reveal_toggle.outerHeight();
                        $reacted_emoji.append($badge);
                        $reacted_emoji.width(size);
                        $reacted_emoji.height(size);
                        $reacted_emoji.show();
                    }
                });
            }
        });
    }

    WpReactionsFront.prototype.isMobile = function () {
        return $(window).width() < 768;
    }

    WpReactionsFront.prototype.numberToPercentage = function (num, total, precision = 0) {
        if (total == 0) return 100 + '%';
        num = num * 100 / total;
        return parseFloat(num).toFixed(precision) + '%';
    };

    WpReactionsFront.prototype.hex2rgba = function (color, opacity) {
        return 'rgba(' + parseInt(color.slice(-6, -4), 16)
            + ',' + parseInt(color.slice(-4, -2), 16)
            + ',' + parseInt(color.slice(-2), 16)
            + ',' + opacity + ')';
    };

    WpReactionsFront.prototype.getEmojiUrl = function (emoji_id, format) {
        const type = emoji_id > 200 ? 'custom' : 'builtin';
        return this.data.emojis_base_url[type] + format + '/' + emoji_id + '.' + format + '?v=' + this.data.version;
    }

    WpReactionsFront.prototype.animate_emojis = function (container = null) {
        let self = this;
        let containers = container == null ? jQuery('.wpra-reactions-container') : container;

        containers.each(function () {
            let container = jQuery(this);
            container.data('animations', []);
            if (container.data('animation') !== true) return;
            self.all_emoji_containers.push(container);
            let emojis = container.find('.wpra-reaction-animation-holder');

            emojis.each(function () {
                let emoji_id = jQuery(this).data('emoji_id');
                self.load_lottie_emoji({
                    container: container,
                    emoji_elem: jQuery(this),
                    emoji_id: emoji_id
                })
            });
        });

        self.checkIfPlayable();
    };

    WpReactionsFront.prototype.load_lottie_emoji = function (params) {

        const defaults = {
            container: null,
            emoji_elem: null,
            emoji_id: 0,
            onComplete: null,
            autoplay: false,
            loop: true
        };

        params = $.extend(defaults, params);

        let animation = bodymovin.loadAnimation({
            container: params.emoji_elem.get(0),
            path: this.getEmojiUrl(params.emoji_id, 'json'),
            renderer: 'svg',
            loop: params.loop,
            autoplay: params.autoplay,
            name: params.emoji_id,
        });

        params.container.data('animations').push(animation);

        if (params.onComplete != null) {
            animation.addEventListener('DOMLoaded', params.onComplete);
            animation.play();
        }
    };

    WpReactionsFront.prototype.checkIfPlayable = function () {
        let self = this;

        jQuery.each(self.all_emoji_containers, function (key, container) {
            if (container.data('animation') !== true) return;
            let elem_top = container.offset().top;
            let isScrolled = jQuery(window).scrollTop() + jQuery(window).height() > elem_top;
            let isDisplayed = container.is(':visible');
            if (container.data('layout') != 'button_reveal') {
                if (isScrolled && isDisplayed && !container.data('isPlaying')) {
                    container.data('isPlaying', true);
                    jQuery.each(container.data('animations'), function (key, emoji) {
                        emoji.play();
                    });
                }
                if ((!isScrolled || !isDisplayed) && container.data('isPlaying')) {
                    container.data('isPlaying', false);
                    jQuery.each(container.data('animations'), function (key, emoji) {
                        emoji.pause();
                    });
                }
            }
        });
    };

    WpReactionsFront.prototype.narrowContainerize = function ($plugin_container, for_button_reveal = false) {
        $plugin_container.find('.wpra-reactions').addClass('wpra-reactions-narrow');
        let reaction_count = $plugin_container.find('.wpra-reaction').length;
        let reactions_width = for_button_reveal ? jQuery(window).width() - 30 : $plugin_container.width();
        $plugin_container.find('.wpra-reaction-emoji-holder').css('width', reactions_width / reaction_count + 'px');
        $plugin_container.find('.wpra-reaction-emoji-holder').css('height', reactions_width / reaction_count + 'px');
        $plugin_container.addClass('wpra-rendered');
    };

    WpReactionsFront.prototype.register_social_click = function (platform, data) {
        $.ajax({
            url: this.data.ajaxurl,
            dataType: 'text',
            type: 'post',
            data: {
                action: 'wpra_handle_user_requests',
                sub_action: 'register_social_click',
                platform: platform,
                bind_id: data.bind_id,
                source: data.source,
                sgc_id: data.sgc_id,
                checker: data.secure
            },
        });
    };

    WpReactionsFront.prototype.wpra_show_reveal = function ($btn) {
        let $reactWrap = $btn.find('.wpra-reactions-wrap');
        let $container = $reactWrap.find('.wpra-reactions-container');
        if ($reactWrap.css('visibility') != 'hidden') {
            return;
        }

        setTimeout(function () {
            if (!$container.data('isPlaying')) {
                $container.data('isPlaying', true);
                $.each($container.data('animations'), function (key, emoji) {
                    emoji.play();
                });
            }
        }, 300);

        $btn.addClass('show-reactions');
        if (!$btn.data('user_reacted')) {
            $reactWrap.show();
            // if button reactions does not fit to its container then narrow them down
            if ($(window).width() < $btn.find('.wpra-reactions').outerWidth() && !$btn.data('narrow_done')) {
                this.narrowContainerize($btn.parents('.wpra-plugin-container'), true);
                $btn.data('narrow_done', true);
            }
        }
        this.centerOntopEmojis($btn);
    };

    WpReactionsFront.prototype.centerOntopEmojis = function ($btn) {
        let $reactWrap = $btn.find('.wpra-reactions-wrap');
        let align = $reactWrap.find('.wpra-reactions-container').data('align');

        this.isMobile() && $reactWrap.css(this.center_on_top_css[align]);
    };

    WpReactionsFront.prototype.register_events = function () {
        let self = this;
        let $document = $(document);

        $document.on({
            mouseenter: function () {
                let $btn = $(this);
                $btn.data('old_styles', $btn.attr('style'));
                let btn_css = $btn.data('hover_css');
                $btn.css(btn_css);
                let $icon = $btn.find('i');
                if ($icon.length > 0) {
                    $icon.data('old_styles', $icon.attr('style'));
                    let icon_css = $icon.data('hover_css');
                    $icon.css(icon_css);
                }
            },
            mouseleave: function () {
                let $btn = $(this);
                $btn.attr('style', $btn.data('old_styles'));
                let $icon = $btn.find('i');
                if ($icon.length > 0) {
                    $icon.attr('style', $icon.data('old_styles'));
                }
            }
        }, ".wpra-reveal-toggle");

        $document.on({
            mouseenter: function () {
                $(this).find('[data-hover_css]').each(function () {
                    $(this).data('old_styles', $(this).attr('style'));
                    $(this).css($(this).data('hover_css'));
                });
            },
            mouseleave: function () {
                if ($(this).hasClass('active')) return;
                $(this).find('[data-hover_css]').each(function () {
                    $(this).attr('style', $(this).data('old_styles'))
                });
            }
        }, ".wpra-layout-bimber .wpra-reaction");

        $document.on('click', '.wpra-reaction', function () {

            let $plugin_container = $(this).parents('.wpra-plugin-container');
            if ($plugin_container.data('flying')) {
                return;
            }

            if (!self.can_user_react) {
                return;
            }

            if (self.data.user_reaction_limitation == 1 && $(this).hasClass('active')) {
                return;
            }

            const emoji_id = $(this).data('emoji_id');
            let $reactions = $(this).parents('.wpra-reactions-container');
            let $social_share = $reactions.find('.wpra-share-wrap');
            const reacted_class = $(this).attr('class').split(" ")[0];
            const bind_id = $reactions.data('bind_id');
            const source = $reactions.data('source');
            let $brother_containers = $('.wpra-reactions-container[data-bind_id=' + bind_id + ']');
            let $reacted_to = $brother_containers.find('.' + reacted_class);
            const layout = $reactions.data('layout');
            const sgc_id = $reactions.data('sgc_id');
            const show_count = $reactions.data('show_count');

            let is_percentage = $reactions.data('count_percentage');
            let $active = $reactions.find('.active');
            let clicked_reaction_count = parseInt($(this).attr('data-count'));
            let active_reaction_count = parseInt($active.attr('data-count'));
            if (isNaN(clicked_reaction_count)) clicked_reaction_count = 0;

            $brother_containers.find('.wpra-reaction').removeClass("active");
            $reacted_to.addClass("active");
            $brother_containers.find('.active').attr("data-count", clicked_reaction_count + 1);
            $brother_containers.find('.active .arrow-badge').show();

            let revert_count = active_reaction_count;
            if (self.data.user_reaction_limitation == 1 && active_reaction_count > 0) {
                revert_count -= 1;
                $active.attr('data-count', revert_count);
                revert_count == 0 ? $active.find('.arrow-badge').hide() : $active.find('.arrow-badge').show();
            }

            if (!is_percentage && active_reaction_count < 1000) {
                $active.find('.count-num').html(revert_count);
            }

            let total_counts = 0;
            $reactions.find('.wpra-reaction').each(function () {
                total_counts += parseInt($(this).attr('data-count'));
            });

            if (is_percentage) {
                $reactions.find('.wpra-reaction').each(function () {
                    let reaction_count = parseInt($(this).attr('data-count'));
                    $(this).find('.count-num').html(self.numberToPercentage(reaction_count, total_counts));
                });
            }

            if (layout == 'bimber') {
                // correct colors for bimber layout when reaction clicked
                $brother_containers.find('.wpra-reaction-label').css({
                    'background-color': $reactions.data('label_bg_color'),
                    'color': $reactions.data('label_text_color')
                });
                $reacted_to.find('.wpra-reaction-label').css({
                    'background-color': $reactions.data('label_bg_color_hover'),
                    'color': $reactions.data('label_text_color_hover')
                });

                $reactions.find('.wpra-reaction').each(function () {
                    let reaction_count = parseInt($(this).attr('data-count'));
                    layout == 'bimber' && $(this).find('.wpra-reaction-track-bar').css('height', self.numberToPercentage(reaction_count, total_counts, 2));
                });
            }

            if ($reactions.data('flying_type') && layout != 'button_reveal') {
                $plugin_container.data('flying', true);
                $brother_containers.find('.wpra-reaction').find('.wpra-flying').removeClass("triggered");
                $reacted_to.find('.wpra-flying').addClass("triggered");
                $brother_containers.find('.wpra-call-to-action').addClass('wpra-hide-cta-temp');

                setTimeout(function () {
                    $brother_containers.find('.wpra-call-to-action').removeClass('wpra-hide-cta-temp');
                    $reacted_to.find('.wpra-flying').removeClass("triggered");
                    $plugin_container.data('flying', false);
                }, 1000);
            }

            if ($reactions.data('flying_type') == 'count') {
                $reacted_to.find('.wpra-flying').html(clicked_reaction_count + 1);
            }

            if (!is_percentage && clicked_reaction_count < 1000) {
                $brother_containers.find('.wpra-reaction.active .count-num').html(clicked_reaction_count + 1);
            }

            if (active_reaction_count > 0) {
                $brother_containers.find('.active .arrow-badge').removeClass('hide-count');
            }

            if (layout == 'disqus' || layout == 'jane') {
                let reaction_color_active = $reactions.data('reaction_color_active');
                $brother_containers.find('.wpra-reaction-wrap').css({
                    'border-color': $reactions.data('reaction_border_color'),
                    'background-color': 'transparent'
                });
                $brother_containers.find('.wpra-reaction-label').css({'color': $reactions.data('label_text_color')});
                $reacted_to.find('.wpra-reaction-wrap').css({
                    'border-color': reaction_color_active,
                    'background-color': self.hex2rgba(reaction_color_active, 0.1)
                });
                $reacted_to.find('.wpra-reaction-label').css({'color': reaction_color_active});
                total_counts < 1000 && $brother_containers.find('.wpra-total-counts > span').text(total_counts);
            }

            (layout == 'disqus' && show_count == 'onclick') && $brother_containers.find('.count-num').show();

            if ($reactions.data('enable_share') && $plugin_container.find('.share-btn').length > 0) {
                $social_share.css('display', 'flex');
            }

            $.ajax({
                url: self.data.ajaxurl,
                dataType: 'json',
                type: 'post',
                data: {
                    action: 'wpra_handle_user_requests',
                    sub_action: 'react',
                    bind_id: bind_id,
                    checker: $reactions.data('react_secure'),
                    emoji_id: emoji_id,
                    source: source,
                    sgc_id: sgc_id
                }
            });

            let $reveal_wrap = $reactions.parents('.wpra-button-reveal-wrap');
            $reveal_wrap.data('ontop_align_centered', false);

            if (layout == 'button_reveal') {
                let $reacted_emoji = $reveal_wrap.find('.wpra-reacted-emoji');
                let $reactions_wrap = $reveal_wrap.find('.wpra-reactions-wrap');
                let $reveal_toggle = $reveal_wrap.find('.wpra-reveal-toggle');
                let $badge = $(this).find('.arrow-badge').clone();
                let $plus_one = $(this).find('.wpra-flying').clone();

                $reacted_emoji.html('');
                $reactions_wrap.hide();
                $reveal_wrap.data('user_reacted', true);

                self.load_lottie_emoji({
                    container: $reactions,
                    emoji_elem: $reveal_wrap.find('.wpra-reacted-emoji'),
                    emoji_id: $(this).data('emoji_id'),
                    onComplete: function () {
                        let size = $reveal_toggle.outerHeight();
                        $reacted_emoji.append($plus_one);
                        $plus_one.addClass('triggered');
                        $reacted_emoji.append($badge);
                        $reacted_emoji.width(size);
                        $reacted_emoji.height(size);
                        $reacted_emoji.show();
                    }
                });

                // if share popup enabled then change button text and class
                if ($reveal_toggle.data('enable_share_popup')) {
                    $reveal_toggle.find('.wpra-button-toggle-text').hide();
                    $reveal_toggle.find('.wpra-button-toggle-text-clicked').show();
                    $reveal_toggle.addClass('share-popup-toggle');
                }
            }

            $plugin_container.trigger('user.reacted', [$reacted_to]);
        });

        $document.on('click', '.share-btn', function () {
            let $share_wrap = $(this).parents('.wpra-share-wrap');
            let share_url = $share_wrap.data('share_url') ? $share_wrap.data('share_url') : window.location.href;
            let platform = $(this).data('platform');
            let platform_url = (self.isMobile() && typeof self.data.social_platforms[platform]['url']['mobile'] != "undefined")
                ? self.data.social_platforms[platform]['url']['mobile']
                : self.data.social_platforms[platform]['url']['desktop'];

            self.register_social_click(platform, {
                bind_id: $share_wrap.data('bind_id'),
                source: $share_wrap.data('source'),
                sgc_id: $share_wrap.data('sgc_id'),
                secure: $share_wrap.data('secure')
            });

            window.open(platform_url + share_url, '_blank', 'width=626, height=436');
        });

        $document.on({
            mouseenter: function () {
                self.can_user_react = false;
                self.wpra_show_reveal($(this));
                setTimeout(function () {
                    self.can_user_react = true;
                }, 500);
            },
            mouseleave: function () {
                $(this).removeClass('show-reactions');
                $(this).find('.wpra-reactions-wrap').hide();
            }
        }, '.wpra-button-reveal-wrap');

        $document.on('click', '.wpra-share-popup-close', function () {
            $('html,body').removeClass('wpra-share-popup-active');
            $('body > .wpra-share-popup').remove();
            $('body > .wpra-share-popup-overlay').remove();
        });

        $document.on('click', '.wpra-plugin-container .share-popup-toggle, .wpra-share-expandable-more .qa-share',
            function () {
                let $plugin_container = $(this).parents('.wpra-plugin-container');
                if ($plugin_container.has('.wpra-share-popup').length) {
                    let $clone = $plugin_container.find('.wpra-share-popup').clone();
                    $('body').append('<div class="wpra-share-popup-overlay"></div>');
                    $('body').append($clone);
                    $('body').addClass('wpra-share-popup-active');
                }
            });

        $(window).scroll(function () {
            self.checkIfPlayable();
        });

        $document.click(function () {
            self.checkIfPlayable();
        });

        $document.on('click', '.wpra-share-expandable-more .qa-times', function () {
            let $expandable = $(this).parents('.wpra-share-expandable');
            $expandable.removeClass('active');
            $expandable.find('.wpra-share-expandable-list').removeClass('active');
            $(this).parent().removeClass('active');
        });

        $document.on({
            mouseenter: function () {
                let $container = $(this).parents('.wpra-reactions-container');
                const format = $container.data('format');

                if (!$container.data('animation')) return;

                // animate single emojis that hovered
                if ($container.data('animation') == 'on_hover') {
                    let $emoji_elem = $(this).find('.wpra-reaction-animation-holder');
                    let $static_emoji = $(this).find('.wpra-reaction-static-holder');
                    const emoji_id = $(this).data('emoji_id');

                    if (format.indexOf('gif') > -1) {
                        const emoji_url = self.getEmojiUrl(emoji_id, 'gif');
                        $static_emoji.find('img').attr('src', emoji_url);
                        return;
                    }

                    if ($emoji_elem.children().length > 0) {
                        $container.data('animations').forEach(function (anim) {
                            if (anim.name == emoji_id) {
                                $static_emoji.hide();
                                $emoji_elem.show();
                                anim.play();
                            }
                        });
                        return;
                    }

                    self.load_lottie_emoji({
                        container: $container,
                        emoji_elem: $emoji_elem,
                        emoji_id: emoji_id,
                        autoplay: true,
                        onComplete: function () {
                            $static_emoji.hide();
                            $emoji_elem.show();
                        }
                    });
                }

                // animate all emojis when one hovered
                if ($container.data('animation') == 'on_hover_all') {

                    if (format.indexOf('gif') > -1) {
                        $container.find('.wpra-reaction').each(function () {
                            const emoji_id = $(this).data('emoji_id');
                            const emoji_url = self.getEmojiUrl(emoji_id, 'gif');
                            $(this).find('img').attr('src', emoji_url);
                        });

                        return;
                    }

                    $container.find('.wpra-reaction-static-holder').hide();
                    $container.find('.wpra-reaction').each(function () {
                        let emoji_id = $(this).data('emoji_id');
                        let $animated = $(this).find('.wpra-reaction-animation-holder');
                        if ($animated.children().length > 0) return;
                        self.load_lottie_emoji({
                            container: $container,
                            emoji_elem: $animated,
                            emoji_id: emoji_id,
                            autoplay: true
                        });
                        $animated.show();
                    });
                }
            },
            mouseleave: function () {
                let $container = $(this).parents('.wpra-reactions-container');
                const format = $container.data('format');

                if (format.indexOf('/') === -1) return;
                if ($container.data('animation') != 'on_hover') return;

                let emoji_id = $(this).data('emoji_id');
                let $static_emoji = $(this).find('.wpra-reaction-static-holder');

                if (format.indexOf('gif') > -1) {
                    const emoji_url = self.getEmojiUrl(emoji_id, 'png');
                    $static_emoji.find('img').attr('src', emoji_url);
                    return;
                }

                let $emoji_elem = $(this).find('.wpra-reaction-animation-holder');
                $(this).find('.wpra-reaction-static-holder').show();
                $emoji_elem.hide();
                $container.data('animations').forEach(function (anim) {
                    anim.pause();
                });
            }
        }, '.wpra-reaction');

        $('.dismiss-alert').click(function () {
            $('.wpra-license-alert-wrap').remove();

            $.post(self.data.ajaxurl, {
                action: 'wpra_handle_admin_requests',
                sub_action: 'dismiss_license_alert'
            });
        });
    }

    window.WpReactionsFront = new WpReactionsFront(wpreactions);
});