<?php

namespace WPRA;

use WPRA\Helpers\Utils;

class Enqueue {

	private $front_assets = [];
	private $admin_assets = [];
	private $hooks = [
		'toplevel_page_wpra-dashboard',
		'wp-reactions_page_wpra-global-options',
		'wp-reactions_page_wpra-shortcode-generator',
		'wp-reactions_page_wpra-my-shortcodes',
		'wp-reactions_page_wpra-analytics',
		'wp-reactions_page_wpra-settings',
		'wp-reactions_page_wpra-tools',
	];

	static function init() {
		return new self();
	}

	public function __construct() {

		// remove bootstrap.js from other themes or plugins in order to avoid collision
		add_action( 'admin_print_scripts', function () {
			global $wp_scripts;
			$screen = get_current_screen();
			if ( ! is_null( $screen ) && in_array( $screen->base, $this->hooks ) ) {
				foreach ( $wp_scripts->queue as $handle ) {
					$this->deregisterScript( $handle );
				}
				foreach ( $wp_scripts->registered as $script ) {
					$this->deregisterScript( $script->handle );
				}
			}
		}, 999 );

		$this->flushAdminAssets();
		$this->flushFrontAssets();
	}

	function deregisterScript( $handle ) {
		if ( $handle == 'wpra-bootstrap' || strpos( $handle, 'bootstrap' ) === false ) {
			return;
		}
		wp_dequeue_script( $handle );
		wp_deregister_script( $handle );
	}

	function registerAdminScripts() {
		$layout = Utils::get_query_var( 'layout' );

		wp_enqueue_script( 'jquery-ui-draggable' );
		wp_enqueue_script( 'jquery-ui-droppable' );

		// add plugin styles
		$this->addAdminAsset( 'style', 'wpra-bootstrap', 'vendor/bootstrap/css/bootstrap.css', $this->hooks );
		$this->addAdminAsset( 'style', 'wpra-apex', 'vendor/apexcharts/apexcharts.css', $this->hooks );
		$this->addAdminAsset( 'style', 'wpra-admin', 'css/admin.css', $this->hooks );
		$this->addAdminAsset( 'style', 'wpra-fontawesome', 'vendor/fontawesome/css/all.min.css', $this->hooks );
		$this->addAdminAsset( 'style', 'wpra-daterangepicker', 'vendor/daterangepicker/daterangepicker.css', [ 'wp-reactions_page_wpra-analytics' ] );
		$this->addAdminAsset( 'style', 'wpra-front', 'css/front.css', $this->hooks );
		$this->addAdminAsset( 'style', 'wpra-common', 'css/common.css' );
		$this->addAdminAsset( 'style', 'wpra-post', 'css/post.css' );
		$this->addAdminAsset( 'style', 'wpra-minicolor', 'vendor/minicolor/jquery.minicolors.css', $this->hooks );
		$this->addAdminAsset( 'font', 'wpra-fonts', 'https://fonts.googleapis.com/css?family=Open+Sans:300,400,500,600,700', $this->hooks );

		// add plugin scripts
		$this->addAdminAsset( 'script', 'wpra-bootstrap', 'vendor/bootstrap/js/wpra.bootstrap.min.js', $this->hooks, [ 'jquery' ] );
		$this->addAdminAsset( 'script', 'wpra-apex', 'vendor/apexcharts/apexcharts.min.js', [ 'wp-reactions_page_wpra-analytics' ] );
		$this->addAdminAsset( 'script', 'wpra-raphael', 'vendor/justgage/raphael-2.1.4.min.js', [ 'wp-reactions_page_wpra-analytics' ] );
		$this->addAdminAsset( 'script', 'wpra-moment', 'vendor/daterangepicker/moment.min.js',
			[ 'wp-reactions_page_wpra-analytics' ],
			[ 'jquery' ]
		);
		$this->addAdminAsset( 'script', 'wpra-daterangepicker', 'vendor/daterangepicker/daterangepicker.js',
			[ 'wp-reactions_page_wpra-analytics' ],
			[ 'jquery', 'wpra-moment' ]
		);

		$this->addAdminAsset( 'script', 'wpra-utils', 'js/utils.js', $this->hooks, [ 'jquery' ] );
		$this->addAdminAsset( 'script', 'wpra-general', 'js/general.js', [], [ 'jquery' ], $this->get_script_vars( 'general' ) );
		$this->addAdminAsset( 'script', 'wpra-analytics', 'js/analytics.js',
			[ 'wp-reactions_page_wpra-analytics' ],
			[ 'jquery', 'wpra-admin', 'wpra-general' ], $this->get_script_vars( 'analytics' )
		);
		$this->addAdminAsset( 'script', 'wpra-justgage', 'vendor/justgage/justgage.js', [ 'wp-reactions_page_wpra-analytics' ] );
		$this->addAdminAsset( 'script', 'wpra-lottie', 'vendor/lottie/lottie.min.js', $this->hooks, [ 'jquery' ] );
		$this->addAdminAsset( 'script', 'wpra-minicolor', 'vendor/minicolor/jquery.minicolors.min.js', $this->hooks, [ 'jquery' ] );
		$this->addAdminAsset( 'script', 'wpra-front', 'js/front.js', $this->hooks, [ 'jquery', 'wpra-lottie' ] );
		$this->addAdminAsset( 'script', 'jquery.ui.touch-punch', 'vendor/jquery.ui.touch-punch.min.js', $this->hooks );
		$this->addAdminAsset( 'script', 'wpra-post', 'js/post.js', [ 'post-new.php', 'post.php' ] );
		$this->addAdminAsset( 'script', 'wpra-admin', 'js/admin.js', $this->hooks,
			[ 'jquery', 'wpra-lottie', 'wpra-front', 'wpra-utils', 'jquery-ui-sortable', 'wpra-bootstrap', 'wpra-general', 'wpra-minicolor' ],
			$this->get_script_vars( 'admin', [
				'min_emojis' => Config::getLayoutValue( $layout, 'min_emojis' ),
				'max_emojis' => Config::getLayoutValue( $layout, 'max_emojis' ),
			] )
		);
	}

	function registerFrontScripts() {
		$this->addFrontAsset( 'style', 'wpra-front', 'css/front.css' );
		$this->addFrontAsset( 'style', 'wpra-fontawesome', 'vendor/fontawesome/css/all.min.css' );
		$this->addFrontAsset( 'script', 'wpra-lottie', 'vendor/lottie/lottie.min.js' );
		$this->addFrontAsset( 'script', 'wpra-front', 'js/front.js', [ 'jquery', 'wpra-lottie' ], $this->get_script_vars( 'front' ) );
	}

	private function get_script_vars( $type, $params = [] ) {
		$vars = [];

		switch ( $type ) {
			case 'analytics':
				$vars = [
					'object' => 'wpra_analytics',
					'vars'   => [
						'ajaxurl'  => Utils::admin_url( 'admin-ajax.php' ),
						'messages' => [
							'no_any_shortcode' => __( 'You have no any shortcode created!', 'wpreactions' ),
						],
					],
				];
				break;
			case 'admin':
				$vars = [
					'object' => 'wpreactions',
					'vars'   => [
						'ajaxurl'                  => Utils::admin_url( 'admin-ajax.php' ),
						'messages'                 => [
							'options_updating'      => __( 'Updating options...', 'wpreactions' ),
							'getting_preview'       => __( 'Getting preview...', 'wpreactions' ),
							'resetting_options'     => __( 'Resetting to factory settings...', 'wpreactions' ),
							'reset_confirm'         => __( 'Are you sure you want to reset to our factory settings?', 'wpreactions' ),
							'global_prev_step'      => __( 'Prev', 'wpreactions' ),
							'global_next_step'      => __( 'Next', 'wpreactions' ),
							'global_go_back'        => __( 'Go Back', 'wpreactions' ),
							'global_start_over'     => __( 'Start Over', 'wpreactions' ),
							'max_shortcode_chars'   => __( 'Please use maximum 100 characters for shortcode name', 'wpreactions' ),
							'sure_leave_sgc'        => __( 'Are your sure you want to leave the shortcode generator?', 'wpreactions' ),
							'sure_leave_global'     => __( 'Are you sure you want to leave without saving your work?', 'wpreactions' ),
							'fill_all_fields'       => __( 'Please fill all fields', 'wpreactions' ),
							'max_emojis_alert'      => __( 'You have reached maximum allowed emojis for the layout', 'wpreactions' ),
							'sure_delete_shortcode' => __( 'Are you sure you want to permanently delete this Shortcode?', 'wpreactions' ),
							'layout_minimal_emojis' => sprintf( __( 'This layout requires at least %d emojis', 'wpreactions' ), $params['min_emojis'] ),
							'has_an_empty_label'    => __( 'Please go to "SETUP" tab and set all labels for emojis', 'wpreactions' ),
							'wrong_range_input'     => __( 'Please enter valid range like 100-500', 'wpreactions' ),
							'no_shortcode_name'     => __( 'Please give a name to your shortcode', 'wpreactions' ),
							'woo_no_shortcode'      => __( 'You must choose shortcode', 'wpreactions' ),
							'woo_empty_hook'        => __( 'Custom hook name can not be empty', 'wpreactions' ),
							'sgc_btn_created'       => __( 'Save Shortcode', 'wpreactions' ),
						],
						'current_options'          => Config::$active_layout_opts,
						'social_platforms'         => Config::$social_platforms,
						'global_lp'                => Utils::getAdminPage( 'global' ),
						'emojis_base_url'          => [
							'builtin' => Emojis::getBaseUrl( 'builtin' ),
							'custom'  => Emojis::getBaseUrl( 'custom' ),
						],
						'version'                  => WPRA_VERSION,
						'user_reaction_limitation' => Config::$settings['user_reaction_limitation'],
						'max_emojis'               => $params['max_emojis'],
						'min_emojis'               => $params['min_emojis'],
						'fontawesome_api'          => Config::$fontawesome_api,
					],
				];
				break;
			case 'general':
				$vars = [
					'object' => 'wpreactions_general',
					'vars'   => [
						'ajaxurl'           => Utils::admin_url( 'admin-ajax.php' ),
						'force_updates_url' => get_site_url( null, '/wp-admin/update-core.php?force-check=1' ),
					],
				];
				break;
			case 'front':
				$vars = [
					'object' => 'wpreactions',
					'vars'   => [
						'ajaxurl'                  => Utils::admin_url( 'admin-ajax.php' ),
						'emojis_base_url'          => [
							'builtin' => Emojis::getBaseUrl( 'builtin' ),
							'custom'  => Emojis::getBaseUrl( 'custom' ),
						],
						'social_platforms'         => Config::$social_platforms,
						'version'                  => WPRA_VERSION,
						'user_reaction_limitation' => Config::$settings['user_reaction_limitation'],
					],
				];
				break;
		}

		return $vars;
	}

	function addFrontAsset( $type, $handle, $url, $deps = [], $locals = [], $footer = true ) {
		$this->front_assets[] = [
			'type'   => $type,
			'handle' => $handle,
			'url'    => $url,
			'deps'   => $deps,
			'footer' => $footer,
			'locals' => $locals,
		];
	}

	function addAdminAsset( $type, $handle, $url, $hooks = [], $deps = [], $locals = [], $footer = true ) {
		$this->admin_assets[] = [
			'type'   => $type,
			'handle' => $handle,
			'url'    => $url,
			'deps'   => $deps,
			'footer' => $footer,
			'hooks'  => $hooks,
			'locals' => $locals,
		];
	}

	function flushFrontAssets() {
		add_action( 'wp_enqueue_scripts', function () {

			$this->registerFrontScripts();

			if ( ! empty( $this->front_assets ) ) {
				foreach ( $this->front_assets as $asset ) {
					$url = Utils::getAsset( $asset['url'] );
					if ( $asset['type'] == 'style' ) {
						wp_enqueue_style( $asset['handle'], $url );
					} else if ( $asset['type'] == 'script' ) {
						wp_enqueue_script( $asset['handle'], $url, $asset['deps'], '', $asset['footer'] );
					} else if ( $asset['type'] == 'font' ) {
						wp_enqueue_style( $asset['handle'], $asset['url'] );
					}

					if ( ! empty( $asset['locals'] ) ) {
						wp_localize_script( $asset['handle'], $asset['locals']['object'], $asset['locals']['vars'] );
					}
				}
			}
		} );
	}

	function flushAdminAssets() {
		add_action( 'admin_enqueue_scripts', function ( $hook ) {

			$this->registerAdminScripts();

			if ( ! empty( $this->admin_assets ) ) {
				foreach ( $this->admin_assets as $asset ) {
					$url = Utils::getAsset( $asset['url'] );
					if ( isset( $asset['hooks'] ) and ( empty( $asset['hooks'] ) or in_array( $hook, $asset['hooks'] ) ) ) {
						if ( $asset['type'] == 'style' ) {
							wp_enqueue_style( $asset['handle'], $url );
						} else if ( $asset['type'] == 'script' ) {
							wp_enqueue_script( $asset['handle'], $url, $asset['deps'], '', $asset['footer'] );
						} else if ( $asset['type'] == 'font' ) {
							wp_enqueue_style( $asset['handle'], $asset['url'] );
						}
					}
					if ( ! empty( $asset['locals'] ) ) {
						wp_localize_script( $asset['handle'], $asset['locals']['object'], $asset['locals']['vars'] );
					}
				}
			}
		} );
	}

} // end of class definition