<?php

use WPRA\App;
use WPRA\Emojis;
use WPRA\Helpers\Utils;
use WPRA\Integrations\WPML;
use WPRA\Shortcode;

$params = [];
if ( isset( $data ) ) {
	extract( $data );
}

if ( empty( $params['source'] ) ) {
	$params['source'] = $params['sgc_id'] == 0 ? 'global' : 'shortcode';
}
$social_platforms = $params['enable_share_buttons'] == 'false' ? '' : Shortcode::getSocialPlatforms( $params );

$title_styles = Utils::buildInlineStyle( [
	'color'               => $params['title_color'],
	'font-size'           => $params['title_size'],
	'font-weight'         => $params['title_weight'],
	'display'             => $params['show_title'] == 'false' ? 'none' : 'block',
	'border-bottom'       => '1px solid #eee',
	'padding-bottom'      => '35px',
	'border-bottom-width' => $params['title_border'] == 'true' ? $params['title_border_size'] : 0,
	'border-bottom-style' => $params['title_border_style'],
	'border-bottom-color' => $params['title_border_color'],
] );

$already      = App::getUserReactedEmoji( $params['bind_id'] );
$start_counts = App::getCountsTotal( $params['bind_id'], $params['start_counts'], $params['emojis'] );

$align       = Utils::flexAlign( $params['align'] );
$wrap_styles = "justify-content: $align;";

$flying_styles = Utils::buildInlineStyle( [
	'color'       => $params['flying']['text_color'],
	'font-size'   => $params['flying']['font_size'],
	'font-weight' => $params['flying']['font_weight'],
] );

$total_counts = array_sum( $start_counts );

$data_atts = Utils::buildDataAttrs( [
	'layout'                 => 'bimber',
	'ver'                    => WPRA_VERSION,
	'bind_id'                => $params['bind_id'],
	'show_count'             => 'true',
	'count_percentage'       => $params['count_percentage'],
	'enable_share'           => $params['enable_share_buttons'],
	'animation'              => $params['animation'],
	'align'                  => $params['align'],
	'flying_type'            => $params['flying']['type'],
	'react_secure'           => wp_create_nonce( 'wpra-react-action' ),
	'source'                 => $params['source'],
	'bar_progress_color'     => $params['bar_progress_color'],
	'label_bg_color'         => $params['label_bg_color'],
	'label_bg_color_hover'   => $params['label_bg_color_hover'],
	'label_text_color'       => $params['label_text_color'],
	'label_text_color_hover' => $params['label_text_color_hover'],
	'sgc_id'                 => $params['sgc_id'],
	'format'                 => $params['emoji_format'],
] );

$reactions_classes = implode( ' ', [
	'size-60px',
	$params['animation'] == 'true' ? 'wpra-animated-emojis' : 'wpra-static-emojis',
] );

$label_hover = json_encode( [
	"background-color" => $params['label_bg_color_hover'],
	"color"            => $params['label_text_color_hover'],
] );

$bar_count_style = Utils::buildInlineStyle( [
	'color'       => $params['bar_count_color'],
	'font-size'   => $params['bar_count_size'],
	'font-weight' => $params['bar_count_weight'],
] );

$title_text = WPML::getTranslation( $params['sgc_id'], 'title_text', $params['title_text'] );
?>
<div class="wpra-reactions-wrap wpra-plugin-container wpra-layout-bimber" style="<?php echo $wrap_styles; ?>;">
    <div class="wpra-reactions-container" <?php echo $data_atts; ?>>
        <div class="wpra-call-to-action" style="<?php echo $title_styles; ?>"><?php echo $title_text; ?></div>
        <div class="wpra-reactions <?php echo $reactions_classes; ?>">
			<?php
			foreach ( $params['emojis'] as $emoji_id ):
				if ( $emoji_id == - 1 ) continue;
				$emoji_count      = isset( $start_counts[ $emoji_id ] ) ? $start_counts[ $emoji_id ] : 0;
				$flying_text      = WPML::getTranslation( $params['sgc_id'], "flying_labels_$emoji_id", $params['flying']['labels'][ $emoji_id ] );
				$start_counts_fmt = Utils::formatCount( $emoji_count, $params['count_percentage'], $total_counts );
				$track_perc       = $total_counts > 0 ? round( $emoji_count * 100 / $total_counts, 2 ) . '%' : '0%';
				$reaction_classes = $already == $emoji_id ? [ "emoji-$emoji_id", 'active' ] : [ "emoji-{$emoji_id}" ];
				$label_style      = sprintf(
					'background-color: %s; color: %s;font-size: %s;font-weight: %s;',
					$already == $emoji_id ? $params['label_bg_color_hover'] : $params['label_bg_color'],
					$already == $emoji_id ? $params['label_text_color_hover'] : $params['label_text_color'],
					$params['label_text_size'],
					$params['label_text_weight']
				);
				$reaction_attrs   = Utils::buildDataAttrs( [ 'count' => $emoji_count, 'emoji_id' => $emoji_id ] );
				?>
                <div class="<?php echo implode( ' ', $reaction_classes ); ?> wpra-reaction" <?php echo $reaction_attrs; ?>>
                    <div class="wpra-flying" style="<?php echo $flying_styles; ?>"><?php echo $flying_text; ?></div>
					<?php Utils::renderTemplate(
						'view/front/single-emoji',
						[
							'animation'    => $params['animation'],
							'emoji_id'     => $emoji_id,
							'emoji_format' => $params['emoji_format'],
							'is_lottie'    => $params['is_lottie'],
						]
					); ?>
                    <div class="wpra-reaction-track" style="background-color: <?php echo $params['bar_background_color']; ?>">
                        <div class="wpra-reaction-track-val count-num" style="<?php echo $bar_count_style; ?>"><?php echo $start_counts_fmt; ?></div>
                        <div class="wpra-reaction-track-bar" style="height: <?php echo $track_perc; ?>; background-color: <?php echo $params['bar_progress_color']; ?>"></div>
                    </div>
                    <div class="wpra-reaction-label" data-hover_css='<?php echo $label_hover; ?>' style="<?php echo $label_style; ?>"><?php echo $flying_text; ?></div>
                </div>
			<?php endforeach; ?>
        </div>
		<?php echo $social_platforms; ?>
    </div> <!-- end of reactions container -->
</div> <!-- end of reactions wrap -->