<?php
use WPRA\Helpers\Utils;
use WPRA\Integrations\WPML;
use WPRA\Shortcode;

$params = [];
if ( isset( $data ) ) {
	extract( $data );
}

// some options are not valid for button reveal, so lets set them to empty string
$params['show_title']           = 'false';
$params['title_color']          = $params['title_size'] = $params['title_weight'] = $params['title_text'] = '';
$params['social_style_buttons'] = $params['enable_share_buttons'] = 'false';
$params['social']               = [
	"border_radius"  => "",
	"border_color"   => "",
	"text_color"     => "",
	"bg_color"       => "",
	"button_type"    => "",
	"hide_titles"    => "",
	"counter"        => "",
	"counter_size"   => "",
	"counter_weight" => "",
	"counter_color"  => "",
];

if (empty($params['source'])) {
	$params['source'] = $params['sgc_id'] == 0 ? 'global' : 'shortcode';
}
$social_platforms = $params['reveal_button']['popup'] == 'false' ? '' : Shortcode::getSocialPlatforms( $params );

$btn_styles = Utils::buildInlineStyle( [
	'border-style'   => 'solid',
	'color'          => $params['reveal_button']['text_color'],
	'font-size'      => $params['reveal_button']['font_size'],
	'font-weight'    => $params['reveal_button']['font_weight'],
	'background'     => $params['reveal_button']['bgcolor'],
	'border-color'   => $params['reveal_button']['border_color'],
	'border-radius'  => $params['reveal_button']['border_radius'],
	'padding-top'    => $params['reveal_button']['padding_top'],
	'padding-bottom' => $params['reveal_button']['padding_bottom'],
	'padding-left'   => $params['reveal_button']['padding_left'],
	'padding-right'  => $params['reveal_button']['padding_right'],
] );

$reveal_btn_hover = json_encode( [
	"background"   => $params['reveal_button']['hover_bgcolor'],
	"border-color" => $params['reveal_button']['hover_border_color'],
	"color"        => $params['reveal_button']['hover_text_color'],
] );

$icon_styles = Utils::buildInlineStyle( [
	'font-size' => $params['reveal_button']['icon_size'],
	'color'     => $params['reveal_button']['icon_color'],
	'margin'    => '0 %s 0 %s',
] );

$button_text_val = WPML::getTranslation( $params['sgc_id'], 'reveal_button_text', $params['reveal_button']['text'] );
$button_text     = '<span>' . $button_text_val . '</span>';
$icon_hover      = json_encode( [ "color" => $params['reveal_button']['icon_hover_color'] ] );
$icon_hover_data = "data-hover_css='$icon_hover'";
$icon            = '<i class="%s" style="' . $icon_styles . '" ' . $icon_hover_data . '></i>';
$is_icon_left    = $params['reveal_button']['icon_position'] == 'left';

if ( $params['reveal_button']['icon_active'] == 'true' ) {
	if ( $is_icon_left ) {
		$icon_first  = sprintf( $icon, $params['reveal_button']['icon'], $params['reveal_button']['icon_space'], '0' );
		$button_text = $icon_first . $button_text;
	} else {
		$icon_first  = sprintf( $icon, $params['reveal_button']['icon'], '0', $params['reveal_button']['icon_space'] );
		$button_text = $button_text . $icon_first;
	}
}

$button_text_clicked_val = WPML::getTranslation( $params['sgc_id'], 'reveal_button_text_clicked', $params['reveal_button']['text_clicked'] );
$button_text_clicked     = '<span>' . $button_text_clicked_val . '</span>';

if ( $params['reveal_button']['icon_clicked_active'] == 'true' ) {
	if ( $is_icon_left ) {
		$icon_clicked        = sprintf( $icon, $params['reveal_button']['icon_clicked'], $params['reveal_button']['icon_space'], '0' );
		$button_text_clicked = $icon_clicked . $button_text_clicked;
	} else {
		$icon_clicked        = sprintf( $icon, $params['reveal_button']['icon_clicked'], '0', $params['reveal_button']['icon_space'] );
		$button_text_clicked = $button_text_clicked . $icon_clicked;
	}
}

$popup_header_text = WPML::getTranslation( $params['sgc_id'], 'reveal_button_popup_header', $params['reveal_button']['popup_header'] );

$reactions_out = Utils::getTemplate(
	'view/front/layouts/regular', [
	'params' => $params,
] );

?>
<div class="wpra-plugin-container wpra-button-reveal" style="justify-content: <?php echo Utils::flexAlign( $params['align'] ); ?>">
	<?php if ( $params['reveal_button']['popup'] == 'true' ) { ?>
        <div class="wpra-share-popup-overlay"></div>
        <div class="wpra-share-popup">
            <span class="wpra-share-popup-close">&times;</span>
            <h3><?php echo $popup_header_text; ?></h3>
			<?php echo $social_platforms; ?>
        </div>
	<?php } ?>
    <div class="wpra-button-reveal-wrap">
        <button type="button" class="wpra-reveal-toggle"
                data-hover_css='<?php echo $reveal_btn_hover; ?>'
                data-enable_share_popup='<?php echo $params['reveal_button']['popup'] ?>'
                style="<?php echo $btn_styles; ?>">
            <span class="wpra-button-toggle-text"><?php echo $button_text; ?></span>
            <span class="wpra-button-toggle-text-clicked" style="display: none"><?php echo $button_text_clicked; ?></span>
        </button>
        <div class="wpra-reacted-emoji"></div>
		<?php echo $reactions_out; ?>
    </div>
</div>