<?php

use WPRA\App;
use WPRA\Helpers\Utils;
use WPRA\Integrations\WPML;
use WPRA\Shortcode;

$params = [];
if ( isset( $data ) ) {
	extract( $data );
}

if ( empty( $params['source'] ) ) {
	$params['source'] = $params['sgc_id'] == 0 ? 'global' : 'shortcode';
}
$social_platforms = $params['enable_share_buttons'] == 'false' ? '' : Shortcode::getSocialPlatforms( $params );

$title_styles = Utils::buildInlineStyle( [
	'color'         => $params['title_color'],
	'font-size'     => $params['title_size'],
	'font-weight'   => $params['title_weight'],
	'display'       => $params['show_title'] == 'false' ? 'none' : 'block',
	'margin-bottom' => $params['show_total_counts'] == 'true' ? '15px' : '35px',
] );

$already      = App::getUserReactedEmoji( $params['bind_id'] );
$start_counts = App::getCountsTotal( $params['bind_id'], $params['start_counts'], $params['emojis'] );

$align       = Utils::flexAlign( $params['align'] );
$wrap_styles = "justify-content: $align;";

$flying_styles = Utils::buildInlineStyle( [
	'color'       => $params['flying']['text_color'],
	'font-size'   => $params['flying']['font_size'],
	'font-weight' => $params['flying']['font_weight'],
] );

$reaction_wrap_style_fmt = Utils::buildInlineStyle( [
	'border-width'     => $params['reaction_border_width'],
	'border-radius'    => $params['reaction_border_radius'],
	'border-style'     => $params['reaction_border_style'],
	'border-color'     => '%s',
	'background-color' => '%s'
] );

$label_style_fmt = Utils::buildInlineStyle( [
	'color'       => '%s',
	'font-size'   => $params['label_text_size'],
	'font-weight' => $params['label_text_weight'],
] );

$count_style = Utils::buildInlineStyle( [
	'color'       => $params['count_text_color'],
	'font-weight' => $params['count_weight'],
	'font-size'   => $params['count_size'],
	'display'     => ( $params['show_count'] == 'true' || ! empty( $already ) ) ? 'block' : 'none',
] );

$total_counts_style = Utils::buildInlineStyle( [
	'color'       => $params['total_counts_color'],
	'font-weight' => $params['total_counts_weight'],
	'font-size'   => $params['total_counts_size'],
] );

$total_counts = array_sum( $start_counts );

$data_atts = Utils::buildDataAttrs( [
	'layout'                => 'disqus',
	'ver'                   => WPRA_VERSION,
	'bind_id'               => $params['bind_id'],
	'show_count'            => $params['show_count'],
	'count_percentage'      => $params['count_percentage'],
	'enable_share'          => $params['enable_share_buttons'],
	'animation'             => $params['animation'],
	'align'                 => $params['align'],
	'flying_type'           => $params['flying']['type'],
	'react_secure'          => wp_create_nonce( 'wpra-react-action' ),
	'source'                => $params['source'],
	'reaction_color_active' => $params['reaction_color_active'],
	'reaction_border_color' => $params['reaction_border_color'],
	'label_text_color'      => $params['label_text_color'],
	'sgc_id'                => $params['sgc_id'],
	'format'                => $params['emoji_format'],
] );

$reactions_classes = implode( ' ', [
	$params['animation'] == 'true' ? 'wpra-animated-emojis' : 'wpra-static-emojis',
	'wpra-reactions-count-' . count( $params['emojis'] ),
] );

$title_text         = WPML::getTranslation( $params['sgc_id'], 'title_text', $params['title_text'] );
$total_counts_title = WPML::getTranslation( $params['sgc_id'], 'total_counts_label', $params['total_counts_label'] );
?>
<div class="wpra-reactions-wrap wpra-plugin-container wpra-layout-disqus" style="<?php echo $wrap_styles; ?>;">
    <div class="wpra-reactions-container" <?php echo $data_atts; ?>>
        <div class="wpra-call-to-action" style="<?php echo $title_styles; ?>"><?php echo $title_text; ?></div>
		<?php if ( $params['show_total_counts'] == 'true' ): ?>
            <div class="wpra-total-counts" style="<?php echo $total_counts_style; ?>">
				<?php echo sprintf( '<span>%s</span> %s', Utils::formatCount( $total_counts ), $total_counts_title ); ?>
            </div>
		<?php endif; ?>
        <div class="wpra-reactions <?php echo $reactions_classes; ?>">
			<?php
			foreach ( $params['emojis'] as $emoji_id ):
				if ( $emoji_id == - 1 ) continue;
				$emoji_count      = isset( $start_counts[ $emoji_id ] ) ? $start_counts[ $emoji_id ] : 0;
				$flying_text      = WPML::getTranslation( $params['sgc_id'], "flying_labels_$emoji_id", $params['flying']['labels'][ $emoji_id ] );
				$start_counts_fmt = Utils::formatCount( $emoji_count, $params['count_percentage'], $total_counts );
				$reaction_classes = $already == $emoji_id ? [ "emoji-$emoji_id", 'active' ] : [ "emoji-$emoji_id" ];
				$reaction_attrs   = Utils::buildDataAttrs( [ 'count' => $emoji_count, 'emoji_id' => $emoji_id ] );

				$label_style = $already == $emoji_id
					? sprintf( $label_style_fmt, $params['reaction_color_active'] )
					: sprintf( $label_style_fmt, $params['label_text_color'] );

				$reaction_wrap_style = $already == $emoji_id
					? sprintf( $reaction_wrap_style_fmt, $params['reaction_color_active'], Utils::hex2rgba( $params['reaction_color_active'], '0.1' ) )
					: sprintf( $reaction_wrap_style_fmt, $params['reaction_border_color'], 'transparent' );
				?>
                <div class="<?php echo implode( ' ', $reaction_classes ); ?> wpra-reaction" <?php echo $reaction_attrs; ?>>
                    <div class="wpra-flying" style="<?php echo $flying_styles; ?>"><?php echo $flying_text; ?></div>
                    <div class="wpra-reaction-wrap" style="<?php echo $reaction_wrap_style; ?>">
						<?php Utils::renderTemplate(
							'view/front/single-emoji',
							[
								'animation'    => $params['animation'],
								'emoji_id'     => $emoji_id,
								'emoji_format' => $params['emoji_format'],
								'is_lottie'    => $params['is_lottie'],
							]
						); ?>
                        <div class="wpra-reaction-label" style="<?php echo $label_style; ?>"><?php echo $flying_text; ?></div>
                    </div>
                    <div class="count-num" style="<?php echo $count_style; ?>"><?php echo $start_counts_fmt; ?></div>
                </div>
			<?php endforeach; ?>
        </div>
		<?php echo $social_platforms; ?>
    </div> <!-- end of reactions container -->
</div> <!-- end of reactions wrap -->