<?php

use WPRA\App;
use WPRA\Helpers\Utils;
use WPRA\Integrations\WPML;
use WPRA\Shortcode;

$params = [];
if ( isset( $data ) ) {
	extract( $data );
}

if ( empty( $params['source'] ) ) {
	$params['source'] = $params['sgc_id'] == 0 ? 'global' : 'shortcode';
}
$social_platforms = $params['enable_share_buttons'] == 'false' ? '' : Shortcode::getSocialPlatforms( $params );

$title_styles = Utils::buildInlineStyle( [
	'color'       => $params['title_color'],
	'font-size'   => $params['title_size'],
	'font-weight' => $params['title_weight'],
	'display'     => $params['show_title'] == 'false' ? 'none' : 'block',
] );

$reactions_styles = Utils::buildInlineStyle( [
	'border-color'  => $params['border_color'],
	'border-width'  => $params['border_width'],
	'border-radius' => $params['border_radius'],
	'border-style'  => $params['border_style'],
	'background'    => $params['bgcolor_trans'] == 'true' ? 'transparent' : $params['bgcolor'],
] );

$already      = App::getUserReactedEmoji( $params['bind_id'] );
$start_counts = App::getCountsTotal( $params['bind_id'], $params['start_counts'], $params['emojis'] );

$align        = $params['layout'] == 'regular' ? Utils::flexAlign( $params['align'] ) : Utils::flexAlign( $params['reveal_button']['ontop_align'] );
$wrap_styles  = "justify-content: {$align};";
$on_top_align = $params['layout'] == 'regular' ? '' : $params['reveal_button']['ontop_align'];

$wrap_classes = [];
if ( $params['layout'] == 'regular' ) {
	$wrap_classes[] = 'wpra-plugin-container';
	$wrap_classes[] = 'wpra-regular';
}

$flying_styles = Utils::buildInlineStyle(
	[
		'color'       => $params['flying']['text_color'],
		'font-size'   => $params['flying']['font_size'],
		'font-weight' => $params['flying']['font_weight'],
	]
);

$total_counts = array_sum( $start_counts );

$data_atts = Utils::buildDataAttrs( [
	'ver'              => WPRA_VERSION,
	'layout'           => $params['layout'],
	'bind_id'          => $params['bind_id'],
	'show_count'       => $params['show_count'],
	'count_percentage' => $params['count_percentage'],
	'enable_share'     => $params['enable_share_buttons'],
	'animation'        => $params['animation'],
	'ontop_align'      => $on_top_align,
	'align'            => $params['align'],
	'flying_type'      => $params['flying']['type'],
	'react_secure'     => wp_create_nonce( 'wpra-react-action' ),
	'source'           => $params['source'],
	'sgc_id'           => $params['sgc_id'],
	'format'           => $params['emoji_format'],
] );

$reactions_classes = [
	'size-' . $params['size'],
	$params['animation'] == 'true' ? 'wpra-animated-emojis' : 'wpra-static-emojis',
];

$shadow_classes = [
	'false'  => '',
	'true'   => 'wpra-shadow-light',
	'light'  => 'wpra-shadow-light',
	'medium' => 'wpra-shadow-medium',
	'hard'   => 'wpra-shadow-hard',
	'dark'   => 'wpra-shadow-dark',
];

$reactions_classes[] = $shadow_classes[ $params['shadow'] ];

$title_text = WPML::getTranslation( $params['sgc_id'], 'title_text', $params['title_text'] );
?>
<div class="wpra-reactions-wrap <?php echo implode( ' ', $wrap_classes ); ?>" style="<?php echo $wrap_styles; ?>;">
    <div class="wpra-reactions-container" <?php echo $data_atts; ?>>
        <div class="wpra-call-to-action" style="<?php echo $title_styles; ?>"><?php echo $title_text; ?></div>
        <div class="wpra-reactions <?php echo implode( ' ', $reactions_classes ); ?>" style="<?php echo $reactions_styles; ?>">
			<?php
			foreach ( $params['emojis'] as $emoji_id ):
				if ( $emoji_id == - 1 ) continue;
				$emoji_count      = isset( $start_counts[ $emoji_id ] ) ? $start_counts[ $emoji_id ] : 0;
				$flying_text      = $params['flying']['type'] == 'count' ? '' : WPML::getTranslation( $params['sgc_id'], "flying_labels_$emoji_id", $params['flying']['labels'][ $emoji_id ] );
				$start_counts_fmt = Utils::formatCount( $emoji_count, $params['count_percentage'], $total_counts );
				$reaction_classes = $already == $emoji_id ? [ "emoji-{$emoji_id}", 'active' ] : [ "emoji-{$emoji_id}" ];
				$reaction_attrs   = Utils::buildDataAttrs( [ 'count' => $emoji_count, 'emoji_id' => $emoji_id ] );
				?>
                <div class="<?php echo implode( ' ', $reaction_classes ); ?> wpra-reaction" <?php echo $reaction_attrs; ?>>
                    <div class="wpra-flying" style="<?php echo $flying_styles; ?>"><?php echo $flying_text; ?></div>
					<?php if ( $params['show_count'] == 'true' ): ?>
                        <div style="background-color: <?php echo $params['count_color']; ?>"
                             class="arrow-badge arrow-bottom-left <?php Utils::echoIf( $emoji_count == 0, 'hide-count' ); ?>">
                            <span style="border-top-color: <?php echo $params['count_color']; ?>" class="tail"></span>
                            <span style="color: <?php echo $params['count_text_color']; ?>" class="count-num"><?php echo $start_counts_fmt; ?></span>
                        </div>
					<?php endif;
					Utils::renderTemplate(
						'view/front/single-emoji',
						[
							'animation'    => $params['animation'],
							'emoji_id'     => $emoji_id,
							'emoji_format' => $params['emoji_format'],
							'is_lottie'    => $params['is_lottie'],
						]
					); ?>
                </div>
			<?php endforeach; ?>
        </div>
		<?php echo $social_platforms; ?>
    </div> <!-- end of reactions container -->
</div> <!-- end of reactions wrap -->