<?php

use WPRA\App;
use WPRA\Config;
use WPRA\Helpers\Utils;

$params = [];
$type   = 'row';

if ( isset( $data ) ) {
	extract( $data );
}

$social_wrap_class = '';
$social_icon_color = '#ffffff';

$social_btn_style = "border-radius: {$params['social']['border_radius']};";

if ( $type == 'expand' && $params['social_style_buttons'] == 'true' ) {

	$social_btn_style .= Utils::buildInlineStyle( [
		'background-color' => $params['social']['bg_color'],
		'border-color'     => $params['social']['border_color'],
		'color'            => $params['social']['text_color'],
	] );

	$social_wrap_class = 'custom-buttons';
	$social_icon_color = $params['social']['text_color'];
}

$wrap_inline = '';
if ( $type == 'expand' ) {
	$social_wrap_class .= ' wpra-share-buttons-' . $params['social']['button_type'];

	if ( $params['enable_share_buttons'] == 'onclick' ) {
		$wrap_inline = 'display: none;';
	}
}

$expandable_inline_css = Utils::buildInlineStyle( [
	'border-radius' => $params['social']['border_radius'],
] );

$share_counter_styles = Utils::buildInlineStyle( [
	'font-size'   => $params['social']['counter_size'],
	'font-weight' => $params['social']['counter_weight'],
	'color'       => $params['social']['counter_color'],
] );

$share_url = is_numeric( $params['bind_id'] ) ? rawurlencode( get_permalink( $params['bind_id'] ) ) : '';
$platforms = [];

foreach ( $params['social_platforms'] as $platform => $status ):
	if ( $status == 'true' ):
		$label = empty( $params['social_labels'][ $platform ] )
			? Config::$social_platforms[ $platform ]['label']
			: $params['social_labels'][ $platform ];

		if ( $params['social']['button_type'] == 'bordered' && $params['social_style_buttons'] == 'false' ) {
			$social_icon_color = Config::$social_platforms[ $platform ]['color'];
		}
		ob_start(); ?>
        <a class="share-btn share-btn-<?php echo $platform; ?>"
           data-platform="<?php echo $platform; ?>" style="<?php echo $social_btn_style; ?>">
            <span class="share-btn-icon"><?php Utils::getSocialIcon( $platform, $social_icon_color, $params['social_style_buttons'] ); ?></span>
            <span class="share-btn-text"><?php echo esc_html($label); ?></span>
        </a>
		<?php
		$platforms[] = ob_get_clean();
	endif;
endforeach;
$active_count = sizeof( $platforms );
$total_count  = App::getTotalShareCounts( $params['bind_id'], isset( $params['social']['fake_count'] ) ? $params['social']['fake_count'] : 0 );

$data_attrs = Utils::buildDataAttrs( [
	'share_url' => $share_url,
	'bind_id'   => $params['bind_id'],
	'source'    => $params['source'],
	'sgc_id'    => $params['sgc_id'],
	'secure'    => wp_create_nonce( 'wpra-share-action' ),
] );

if ( $type == 'row' ): ?>
    <div class="wpra-share-wrap wpra-share-buttons <?php echo $social_wrap_class; ?>"
         style="<?php echo $wrap_inline; ?>" <?php echo $data_attrs; ?>>
		<?php foreach ( $platforms as $platform ):
			echo $platform;
		endforeach; ?>
    </div>
<?php elseif ( $type == 'expand' ):
	$init_count = $active_count >= 5 ? 5 : $active_count ?>
    <div class="wpra-share-wrap wpra-share-expandable"
         style="<?php Utils::echoIf( $params['enable_share_buttons'] == 'onclick', 'display:none;' ); ?>" <?php echo $data_attrs; ?>>
		<?php if ( $params['social']['counter'] == 'true' ): ?>
            <div class="wpra-share-expandable-counts" style="<?php echo $share_counter_styles; ?>">
                <span><?php echo $total_count; ?></span>
                <span><?php _e( 'Shares', 'wpreactions' ); ?></span>
            </div>
		<?php endif; ?>
        <div class="wpra-share-buttons <?php echo $social_wrap_class; ?>">
			<?php for ( $i = 0; $i < $init_count; $i ++ ):
				echo $platforms[ $i ];
			endfor;
			if ( $active_count > 5 ): ?>
                <div class="wpra-share-expandable-popup">
                    <div class="wpra-share-popup-overlay"></div>
                    <div class="wpra-share-popup">
                        <span class="wpra-share-popup-close">&times;</span>
                        <h3>Share this post!</h3>
                        <div class="wpra-share-buttons">
							<?php foreach ( $platforms as $index => $platform ):
								echo $platform;
							endforeach; ?>
                        </div>
                    </div>
                </div>
			<?php endif; ?>
        </div>
		<?php if ( $active_count > 5 ): ?>
            <div class="wpra-share-expandable-more" style="<?php echo $expandable_inline_css; ?>">
                <i class="qa qa-share" title="More platforms"></i>
            </div>
		<?php endif; ?>
    </div>
<?php endif; ?>